==> jc-1.4.0.tar.gz: java/awt/geom/Ellipse2D__24Float.h <==
// public class java.awt.geom.Ellipse2D$Float

// class file dependencies
// @dep_class 718dd7c671fd5bb1 java_awt_geom_Ellipse2D
// @dep_class 639722d9c1505bd4 java_awt_geom_Ellipse2D__24Float
// @dep_class bfc51dd0f2a7e666 java_awt_geom_RectangularShape
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_geom_Ellipse2D

#include "java/awt/geom/Ellipse2D.h"

#ifndef _JC_java_awt_geom_Ellipse2D__24Float_H_
#define _JC_java_awt_geom_Ellipse2D__24Float_H_

// Forward structure declarations
struct _jc_java_awt_geom_Rectangle2D$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_geom_Ellipse2D__24Float$sub_refs	_jc_java_awt_geom_Ellipse2D__24Float$sub_refs;
typedef struct _jc_java_awt_geom_Ellipse2D__24Float$sub_nonrefs	_jc_java_awt_geom_Ellipse2D__24Float$sub_nonrefs;
typedef struct _jc_java_awt_geom_Ellipse2D__24Float$refs	_jc_java_awt_geom_Ellipse2D__24Float$refs;
typedef struct _jc_java_awt_geom_Ellipse2D__24Float$nonrefs	_jc_java_awt_geom_Ellipse2D__24Float$nonrefs;
typedef struct _jc_java_awt_geom_Ellipse2D__24Float$object	_jc_java_awt_geom_Ellipse2D__24Float$object;

typedef const struct _jc_java_awt_geom_Ellipse2D__24Float$vmethods	_jc_java_awt_geom_Ellipse2D__24Float$vmethods;
typedef const struct _jc_java_awt_geom_Ellipse2D__24Float$vtable	_jc_java_awt_geom_Ellipse2D__24Float$vtable;
typedef const struct _jc_java_awt_geom_Ellipse2D__24Float$vtype	_jc_java_awt_geom_Ellipse2D__24Float$vtype;

// Constructors
extern void _jc_java_awt_geom_Ellipse2D__24Float$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *);
extern void _jc_java_awt_geom_Ellipse2D__24Float$method$_init$93ce2350ea2eb97e(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *, jfloat, jfloat, jfloat, jfloat);

// Virtual methods
extern struct _jc_java_awt_geom_Rectangle2D$object *_jc_java_awt_geom_Ellipse2D__24Float$method$getBounds2D$465501a912b32d22(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *);
extern jdouble _jc_java_awt_geom_Ellipse2D__24Float$method$getHeight$099466d7bee38f0e(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *);
extern jdouble _jc_java_awt_geom_Ellipse2D__24Float$method$getWidth$7f6d44448448d217(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *);
extern jdouble _jc_java_awt_geom_Ellipse2D__24Float$method$getX$da8367f71985b05b(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *);
extern jdouble _jc_java_awt_geom_Ellipse2D__24Float$method$getY$cea2a8c824df48e5(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *);
extern jboolean _jc_java_awt_geom_Ellipse2D__24Float$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *);
extern void _jc_java_awt_geom_Ellipse2D__24Float$method$setFrame$845dc00ca29ef2db(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *, jdouble, jdouble, jdouble, jdouble);
extern void _jc_java_awt_geom_Ellipse2D__24Float$method$setFrame$1eb9975ee7bbbc3c(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *, jfloat, jfloat, jfloat, jfloat);

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Float$method_info$getBounds2D$465501a912b32d22;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Float$method_info$getHeight$099466d7bee38f0e;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Float$method_info$getWidth$7f6d44448448d217;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Float$method_info$getX$da8367f71985b05b;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Float$method_info$getY$cea2a8c824df48e5;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Float$method_info$isEmpty$551bea84f4e0f0cb;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Float$method_info$setFrame$845dc00ca29ef2db;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Float$method_info$setFrame$1eb9975ee7bbbc3c;

// Virtual methods structure
struct _jc_java_awt_geom_Ellipse2D__24Float$vmethods {
	struct _jc_java_awt_geom_Rectangle2D$object	*(*getBounds2D$465501a912b32d22)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *);
	jdouble	(*getHeight$099466d7bee38f0e)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *);
	jdouble	(*getWidth$7f6d44448448d217)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *);
	jdouble	(*getX$da8367f71985b05b)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *);
	jdouble	(*getY$cea2a8c824df48e5)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *);
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *);
	void	(*setFrame$845dc00ca29ef2db)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *, jdouble, jdouble, jdouble, jdouble);
	void	(*setFrame$1eb9975ee7bbbc3c)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *, jfloat, jfloat, jfloat, jfloat);
};

// Vtable
struct _jc_java_awt_geom_Ellipse2D__24Float$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_RectangularShape$vmethods	java_awt_geom_RectangularShape;
	_jc_java_awt_geom_Ellipse2D$vmethods	java_awt_geom_Ellipse2D;
	_jc_java_awt_geom_Ellipse2D__24Float$vmethods	java_awt_geom_Ellipse2D__24Float;
};

// Vtype
struct _jc_java_awt_geom_Ellipse2D__24Float$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Ellipse2D__24Float$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Ellipse2D__24Float$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Ellipse2D__24Float$refs {
    _jc_java_awt_geom_Ellipse2D__24Float$sub_refs	java_awt_geom_Ellipse2D__24Float;
    _jc_java_awt_geom_Ellipse2D$sub_refs	java_awt_geom_Ellipse2D;
    _jc_java_awt_geom_RectangularShape$sub_refs	java_awt_geom_RectangularShape;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Ellipse2D__24Float$sub_nonrefs {
	jfloat	height;
	jfloat	width;
	jfloat	x;
	jfloat	y;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Ellipse2D__24Float$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_RectangularShape$sub_nonrefs	java_awt_geom_RectangularShape;
    _jc_java_awt_geom_Ellipse2D$sub_nonrefs	java_awt_geom_Ellipse2D;
    _jc_java_awt_geom_Ellipse2D__24Float$sub_nonrefs	java_awt_geom_Ellipse2D__24Float;
};

// Object instance structure
struct _jc_java_awt_geom_Ellipse2D__24Float$object {
	_jc_java_awt_geom_Ellipse2D__24Float$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Ellipse2D__24Float$vtype	*vtype;
	_jc_java_awt_geom_Ellipse2D__24Float$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Ellipse2D__24Float$vtype _jc_java_awt_geom_Ellipse2D__24Float$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Ellipse2D__24Float, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Ellipse2D__24Float$class_object;

#endif	/* _JC_java_awt_geom_Ellipse2D__24Float_H_ */

==> jc-1.4.6.tar.gz: java/awt/geom/Ellipse2D__24Float.h <==
// public class java.awt.geom.Ellipse2D$Float

// class file dependencies
// @dep_class 718dd7c671fd5bb1 java_awt_geom_Ellipse2D
// @dep_class 639722d9c1505bd4 java_awt_geom_Ellipse2D__24Float
// @dep_class bfc51dd0f2a7e666 java_awt_geom_RectangularShape
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_geom_Ellipse2D

#include "java/awt/geom/Ellipse2D.h"

#ifndef _JC_java_awt_geom_Ellipse2D__24Float_H_
#define _JC_java_awt_geom_Ellipse2D__24Float_H_

// Forward structure declarations
struct _jc_java_awt_geom_Rectangle2D$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_geom_Ellipse2D__24Float$sub_refs	_jc_java_awt_geom_Ellipse2D__24Float$sub_refs;
typedef struct _jc_java_awt_geom_Ellipse2D__24Float$sub_nonrefs	_jc_java_awt_geom_Ellipse2D__24Float$sub_nonrefs;
typedef struct _jc_java_awt_geom_Ellipse2D__24Float$refs	_jc_java_awt_geom_Ellipse2D__24Float$refs;
typedef struct _jc_java_awt_geom_Ellipse2D__24Float$nonrefs	_jc_java_awt_geom_Ellipse2D__24Float$nonrefs;
typedef struct _jc_java_awt_geom_Ellipse2D__24Float$object	_jc_java_awt_geom_Ellipse2D__24Float$object;

typedef const struct _jc_java_awt_geom_Ellipse2D__24Float$vmethods	_jc_java_awt_geom_Ellipse2D__24Float$vmethods;
typedef const struct _jc_java_awt_geom_Ellipse2D__24Float$vtable	_jc_java_awt_geom_Ellipse2D__24Float$vtable;
typedef const struct _jc_java_awt_geom_Ellipse2D__24Float$vtype	_jc_java_awt_geom_Ellipse2D__24Float$vtype;

// Constructors
extern void _jc_java_awt_geom_Ellipse2D__24Float$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_Ellipse2D__24Float$method$_init$93ce2350ea2eb97e(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *, jfloat, jfloat, jfloat, jfloat) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_geom_Rectangle2D$object *_jc_java_awt_geom_Ellipse2D__24Float$method$getBounds2D$465501a912b32d22(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *) _JC_JCNI_ATTR;
extern jdouble _jc_java_awt_geom_Ellipse2D__24Float$method$getHeight$099466d7bee38f0e(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *) _JC_JCNI_ATTR;
extern jdouble _jc_java_awt_geom_Ellipse2D__24Float$method$getWidth$7f6d44448448d217(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *) _JC_JCNI_ATTR;
extern jdouble _jc_java_awt_geom_Ellipse2D__24Float$method$getX$da8367f71985b05b(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *) _JC_JCNI_ATTR;
extern jdouble _jc_java_awt_geom_Ellipse2D__24Float$method$getY$cea2a8c824df48e5(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_geom_Ellipse2D__24Float$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_Ellipse2D__24Float$method$setFrame$845dc00ca29ef2db(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *, jdouble, jdouble, jdouble, jdouble) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_Ellipse2D__24Float$method$setFrame$1eb9975ee7bbbc3c(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *, jfloat, jfloat, jfloat, jfloat) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Float$method_info$getBounds2D$465501a912b32d22;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Float$method_info$getHeight$099466d7bee38f0e;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Float$method_info$getWidth$7f6d44448448d217;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Float$method_info$getX$da8367f71985b05b;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Float$method_info$getY$cea2a8c824df48e5;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Float$method_info$isEmpty$551bea84f4e0f0cb;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Float$method_info$setFrame$845dc00ca29ef2db;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Float$method_info$setFrame$1eb9975ee7bbbc3c;

// Virtual methods structure
struct _jc_java_awt_geom_Ellipse2D__24Float$vmethods {
	struct _jc_java_awt_geom_Rectangle2D$object	*(*getBounds2D$465501a912b32d22)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *) _JC_JCNI_ATTR;
	jdouble	(*getHeight$099466d7bee38f0e)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *) _JC_JCNI_ATTR;
	jdouble	(*getWidth$7f6d44448448d217)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *) _JC_JCNI_ATTR;
	jdouble	(*getX$da8367f71985b05b)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *) _JC_JCNI_ATTR;
	jdouble	(*getY$cea2a8c824df48e5)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *) _JC_JCNI_ATTR;
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *) _JC_JCNI_ATTR;
	void	(*setFrame$845dc00ca29ef2db)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *, jdouble, jdouble, jdouble, jdouble) _JC_JCNI_ATTR;
	void	(*setFrame$1eb9975ee7bbbc3c)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Float$object *, jfloat, jfloat, jfloat, jfloat) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_geom_Ellipse2D__24Float$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_RectangularShape$vmethods	java_awt_geom_RectangularShape;
	_jc_java_awt_geom_Ellipse2D$vmethods	java_awt_geom_Ellipse2D;
	_jc_java_awt_geom_Ellipse2D__24Float$vmethods	java_awt_geom_Ellipse2D__24Float;
};

// Vtype
struct _jc_java_awt_geom_Ellipse2D__24Float$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Ellipse2D__24Float$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Ellipse2D__24Float$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Ellipse2D__24Float$refs {
    _jc_java_awt_geom_Ellipse2D__24Float$sub_refs	java_awt_geom_Ellipse2D__24Float;
    _jc_java_awt_geom_Ellipse2D$sub_refs	java_awt_geom_Ellipse2D;
    _jc_java_awt_geom_RectangularShape$sub_refs	java_awt_geom_RectangularShape;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Ellipse2D__24Float$sub_nonrefs {
	jfloat	height;
	jfloat	width;
	jfloat	x;
	jfloat	y;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Ellipse2D__24Float$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_RectangularShape$sub_nonrefs	java_awt_geom_RectangularShape;
    _jc_java_awt_geom_Ellipse2D$sub_nonrefs	java_awt_geom_Ellipse2D;
    _jc_java_awt_geom_Ellipse2D__24Float$sub_nonrefs	java_awt_geom_Ellipse2D__24Float;
};

// Object instance structure
struct _jc_java_awt_geom_Ellipse2D__24Float$object {
	_jc_java_awt_geom_Ellipse2D__24Float$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Ellipse2D__24Float$vtype	*vtype;
	_jc_java_awt_geom_Ellipse2D__24Float$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Ellipse2D__24Float$vtype _jc_java_awt_geom_Ellipse2D__24Float$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Ellipse2D__24Float, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Ellipse2D__24Float$class_object;

#endif	/* _JC_java_awt_geom_Ellipse2D__24Float_H_ */
